@@ -7,8 +7,8 @@
 # Created Time: 2021-03-20
 # Description:
 # -----------------------------------------------------------------------#
-from pathlib import Path
+import os
 
-KNLP_PATH = f"{Path.cwd()}"
+KNLP_PATH = os.path.dirname(os.path.realpath(__file__)) + "/../.."
 sentence_delimiters = ['?', '!', ';', '？', '！', '。', '；', '……', '…', '\n']
 allow_speech_tags = ['an', 'i', 'j', 'l', 'n', 'nr', 'nrfg', 'ns', 'nt', 'nz', 't', 'v', 'vd', 'vn', 'eng']
