@@ -10,5 +10,6 @@
 
 from knlp.seq_labeling.inference import seg, ner
 from knlp.seq_labeling.utils import evaluation_seg, evaluation_seg_files
+from knlp.seq_labeling.seg import Segmentor
 
-__all__ = ["seg", "ner", "evaluation_seg", "evaluation_seg_files"]
+__all__ = ["seg", "ner", "evaluation_seg", "evaluation_seg_files", "Segmentor"]
